%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute trend, annual and semiannual signal
%
% --Input--
%   time          time in decimal years (p x 1)
%   data          data (p x 1), p...#timesteps
%   mod           choose 'annual' if only the annual signal should be
%                 included in the parameter estimation, choose 'semiannual' 
%                 if additionally semi-annual signals should be included
%
% --Output--
%   param         estimated parameters (#param x 1)
%                 Parameters: bias, trend, two components of the annual
%                 signal, two components of the semiannual signal.
%   dataApprox    data approximated by the estimated parameters (p x 1)
%
% Author: Anne Springer
% Date:  2020-09-16
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [param, dataApprox] = fitTrend(time, data, mod)

l = length(data);
omega = 2*pi;

% Functional model
switch mod
    case 'annual' % only annual
        A = [ones(l,1) time cos(omega*time) sin(omega*time)];
    case 'semiannual' % annual and semiannual
        A = [ones(l,1)  time cos(omega*time) sin(omega*time) cos(2*omega*time) sin(2*omega*time)];
end

% Estimate parameters
param = A\data;
dataApprox = A*param;

end
