%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute trend, annual and semiannual signal
%
% --Input--
%   time          time in decimal years (p x 1)
%   data          data (n x m x p), n... #lon, m... #lat, p...#timesteps
%   mod           choose 'annual' if only the annual signal should be
%                 included in the parameter estimation, choose 'semiannual' 
%                 if additionally semi-annual signals should be included
%
% --Output--
%   param         estimated parameters (n x m x #param)
%                 Parameters: bias, trend, two components of the annual
%                 signal, two components of the semiannual signal.
%   dataApprox    data approximated by the estimated parameters (n x m x p)
%
% Author: Anne Springer
% Date:  2020-09-16
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [param, dataApprox] = fitTrend2D(time, data, mod)

% Reshape data
j = size(data,1);
k = size(data,2);
l = size(data,3);
omega = 2*pi;
data = reshape(data,j*k,l);

% Functional model
switch mod
    case 'annual' % only annual
        A = [ones(l,1) time cos(omega*time) sin(omega*time)];
    case 'semiannual' % annual and semiannual
        A = [ones(l,1)  time cos(omega*time) sin(omega*time) cos(2*omega*time) sin(2*omega*time)];
end

% Estimate parameters
param = A\data';
dataApprox = A*param;
param = param';
dataApprox = dataApprox';

% Reshape data
param = reshape(param,j,k,size(param,2));
dataApprox = reshape(dataApprox,j,k,l);

end
