function [IN, Lon, Lat] =   selectPolygon(lon,lat,polygon)

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Select longitudes and latitudes located within a polygon
%
% --Input--
%   lon             longitudes (n x 1)
%   lat             latitudes  (m x 1)
%   polygon         lon and lat of polygon (b x 2)

% --Output--
%   IN              index of data points within the polygon (n*m x 1)
%   Lon             Longitudes corresponding to the data points within the
%                   polygon (c x 1)
%   Lat             Latitudes corresponding to the data points within the
%                   polygon (c x 1)
%
% Author: Anne Springer
% Date:  2020-09-16
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Lon = repmat(lon,1,length(lat))';
Lat = repmat(lat,1,length(lon));

IN = inpolygon(Lon(:), Lat(:), polygon(:,1), polygon(:,2));
Lon = Lon(IN);
Lat = Lat(IN);