function showData(data,longitude,latitude,titleString, label, clim, cmap, reverse)

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Visualization of (global) gridded data sets.
%
% --Input--
%   data            matrix containing the data values (n x m)
%   longitude       longitude values of the grid points (n x 1)
%   latitude        latitude values of the grid points (m x 1)
%   title           string with title
%   label           string with label
%   clim            2x1 vector with lower and upper limit of colorbar, e.g.
%                   [-100 100]
%   cmap            choice of colormap: e.g. jet, parula
%   reverse         boolean: if reverse==1 invert colormap
%
% --Output--
%   2D-plot of the gridded values
%
% Author: Anne Springer
% Date:  2020-09-16
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


if nargin<8; reverse=0; end % PA
if nargin<7; cmap=jet; end
if nargin<6; clim=NaN; end
if nargin<5; label='mm'; end
if nargin<4; error('Function showData needs at least 4 input variables'); end

if size(data,2)==1
    data = reshape(data,length(latitude),length(longitude));
end

% flip data array for plot
data=data(end:-1:1,:);

% Plot properties
fs = 12;
f = figure('Position',[1,1,500,300]);
% set(gca,'position',[0.15 0.15 0.7,0.7])
set(gcf,'PaperPositionMode','auto')
set(gca,'FontSize',fs);

% Plot
coast = load('coast30.mat');
idx = coast.lam >=180;
coast.lam(idx) = coast.lam(idx)-360;
hold on
imagesc([min(longitude) max(longitude)],[min(latitude) max(latitude)],data);
if (reverse == 1)
    colormap(flipud(cmap))
else
    colormap(cmap)
end
cb = colorbar;
plot(coast.lam,coast.phi,'k','LineWidth',1);
axis([-180 180 -90 90])
if ~isnan(clim)
    caxis(clim);
end

zlab = get(cb,'xlabel');
set(zlab,'String',label);
title(titleString);
set(gcf,'name',titleString)
xlim tight

end