function showEOF(EOF,longitude,latitude,i,titleString)
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Visualization of the spatial pattern of one specific EOF with the index i. 
%
% --Input--
%   EOF             vector containing the gridded values of the one EOF to 
%                   be plotted (n*m x 1, e.g. 64800 x 1)
%   longitude       longitude values of the grid points (n x 1, e.g. 360 x 1)
%   latitude        latitude values of the grid points (m x 1, e.g. 180 x 1)
%   i               index of the EOF to be visualized (EOFs are sorted
%                   according to size of eigenvalue)
%   titleString     string with title
%
% --Output--
%   Plot of the spatial pattern.
%
%
% Author: Anne Springer
% Date:  2020-09-16
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

EOF = reshape(EOF,180,360);
EOF=EOF(end:-1:1,:); % flip EOF array for plot

fs = 12; % Fontsize
figure('Position',[1,1,400,300]);
set(gcf,'PaperPositionMode','auto')
set(gca,'FontSize',fs);

coast = load('coast30.mat');
idx = coast.lam >=180;
coast.lam(idx) = coast.lam(idx)-360;
hold on

imagesc([min(longitude) max(longitude)],[min(latitude) max(latitude)],EOF);
colormap(flipud(jet))
plot(coast.lam,coast.phi,'k','LineWidth',2);
% axis equal
axis([-180 180 -90 90])
cb = colorbar;


title(strcat(titleString,'-EOF',num2str(i)))
set(gcf,'name',strcat(titleString,'-EOF',num2str(i)))


end