function showEOFlocal(EOF,longitude,latitude,border, i, titleString)

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Visualization of the spatial pattern of one specific EOF with the index i
% on a spatial domain limited by the polygon border.
% Attention: longitude and latitude must have the same number of entries
% corresponding to the number of grid points within the polygon
%
% --Input--
%   EOF             vector containing the gridded values of the one EOF to 
%                   be plotted (n x 1)
%   longitude       longitude values of the grid points (n x 1)
%   latitude        latitude values of the grid points (n x 1)
%   border          matrix which contains the polygon around the regional
%                   area 
%   i               index of the EOF to be visualized (EOFs are sorted
%                   according to size of eigenvalue)
%   titleString     string with title
%
% --Output--
%   Plot of the spatial pattern for a regional area.
%
% Author: Anne Springer
% Date:  2020-09-16
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


x = (min(longitude):1:max(longitude))';
y = (max(latitude):-1:min(latitude))';
X = repmat(x,1,length(y))';
Y = repmat(y,1,length(x));


dataRect = NaN(size(X));

IN = inpolygon(X, Y, border(:,1), border(:,2));
dataRect(IN==1) = EOF;

dataRect=dataRect(end:-1:1,:); % flip EOF array for plot
margin=5;

fs = 12; % Fontsize
figure('Position',[1,1,400,300]);
set(gcf,'PaperPositionMode','auto')
set(gca,'FontSize',fs);
coast = load('coast30.mat');
idx = coast.lam >=180;
coast.lam(idx) = coast.lam(idx)-360;
hold on

imagesc([min(border(:,1)) max(border(:,1))],[min(border(:,2)) max(border(:,2))],dataRect);
colormap(flipud(jet))
%caxis([-0.03 0.03]);
plot(coast.lam,coast.phi,'k','LineWidth',2);
plot(border(:,1),border(:,2),'-r','LineWidth',2);
% axis equal;
axis ([min(border(:,1))-margin max(border(:,1))+margin min(border(:,2))-margin max(border(:,2))+margin])
cb = colorbar;
zlab = get(cb,'xlabel');
%set(zlab,'String','m');

title(strcat(titleString,'-EOF',num2str(i)))
set(gcf,'name',strcat(titleString,'-EOF',num2str(i)))

end