function showPCs(PCs,time,i,legendStrings)
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Visualization of the principle component with the index i.
%
% --Input--
%   PCs             matrix containing the principle components which shall
%                   be visualized (p x u), with p... number of time steps
%                   and u... number of components/models
%   time            matrix with [years months] (p x 2)
%   i               index of the EOF to be visualized (EOFs are sorted
%                   according to size of eigenvalue)
%   legendStrings   legend entries {'entry1', 'entry2'}
%
% --Output--
%   Plot of the principle component.
%
% Author: Anne Springer
% Date:  2020-09-16
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

time = datenum(time(:,1),time(:,2),15*ones(length(time),1));

fs = 12; % Fontsize
ms = 20; % MarkerSize
lw = 2;  % LineWidth

figure('Position',[1,1,800,300]);
set(gcf,'PaperPositionMode','auto')
set(gca,'FontSize',fs);
hold on

for j = 1:size(PCs,2)
    plot(time,PCs(:,j),'MarkerSize',ms,'LineWidth',lw);
    %ylim([-10 10]);
    datetick('x','yy');
end
title(strcat('PC',num2str(i)))
xlabel('year')
ylabel('[mm]')
legend(legendStrings,'Location','EastOutside')
set(gcf,'name',strcat('PC',num2str(i)))
xlim tight

end